@@ -126,6 +126,24 @@ def test_aqua_ubuntu3_json():
         return json.loads(fp.read())
 
 
+@pytest.fixture
+def test_aqua_ubuntu4_json():
+    test_cve_data = os.path.join(
+        os.path.dirname(os.path.realpath(__file__)), "data", "CVE-2022-32081.json"
+    )
+    with open(test_cve_data, "r") as fp:
+        return json.loads(fp.read())
+
+
+@pytest.fixture
+def test_aqua_ubuntu5_json():
+    test_cve_data = os.path.join(
+        os.path.dirname(os.path.realpath(__file__)), "data", "CVE-2022-3821.json"
+    )
+    with open(test_cve_data, "r") as fp:
+        return json.loads(fp.read())
+
+
 @pytest.fixture
 def test_aqua_redhat_json():
     test_cve_data = os.path.join(
@@ -380,7 +398,8 @@ def test_aqua_convert(
     cve_data = aqualatest.convert(test_aqua_ubuntu_json)
     assert cve_data
     cve_data = aqualatest.convert(test_aqua_ubuntu1_json)
-    assert not cve_data
+    assert cve_data
+    assert len(cve_data) == 2
     cve_data = aqualatest.convert(test_aqua_ubuntu2_json)
     assert cve_data
     cve_data = aqualatest.convert(test_aqua_ubuntu3_json)
@@ -416,3 +435,13 @@ def test_aqua_convert(
     cve_data = aqualatest.convert(test_aqua_debian7_json)
     assert cve_data
     assert len(cve_data) == 1
+
+
+def test_ubuntu_convert(test_aqua_ubuntu4_json, test_aqua_ubuntu5_json):
+    aqualatest = AquaSource()
+    cve_data = aqualatest.convert(test_aqua_ubuntu4_json)
+    assert cve_data
+    assert len(cve_data) == 7
+    cve_data = aqualatest.convert(test_aqua_ubuntu5_json)
+    assert cve_data
+    assert len(cve_data) == 7
